@@ -490,7 +490,7 @@ int          tputmine::initpm(  char mt, const pvehicle eht )
       return -119;
    }
    if (mienenlegen || mienenraeumen)
-      initsearch( MapCoordinate( getxpos(),getypos()), int(ceil(float(weapon->mindistance) / maxmalq)), weapon->maxdistance / maxmalq );
+      initsearch( MapCoordinate( getxpos(),getypos()), (weapon->mindistance + maxmalq-1) / maxmalq, weapon->maxdistance / maxmalq );
    return 0;
 }
 
@@ -1146,13 +1146,13 @@ void tsearchreactionfireingunits :: init ( pvehicle vehicle, const AStar3D::Path
    int y1 = maxint;
    int x2 = 0;
    int y2 = 0;
-   int i, j, h;
+   int j, h;
 
    if ( maxshootdist[0] == -1 ) {
-      for (i = 0; i < 8; i++ )
+      for (int i = 0; i < 8; i++ )
          maxshootdist[i] = 0;
 
-      for (i = 0; i < vehicleTypeRepository.getNum(); i++ ) {
+      for (int i = 0; i < vehicleTypeRepository.getNum(); i++ ) {
          pvehicletype fzt = vehicleTypeRepository.getObject_byPos ( i );
          if ( fzt )
             for (j = 0; j < fzt->weapons.count; j++ )
@@ -1204,7 +1204,7 @@ void tsearchreactionfireingunits :: init ( pvehicle vehicle, const AStar3D::Path
 
       }
    if ( getfield(vehicle->xpos, vehicle->ypos)->vehicle == vehicle )
-      for ( i = 0; i < 8; i++ )
+      for ( int i = 0; i < 8; i++ )
          if ( fieldvisiblenow ( getfield ( vehicle->xpos, vehicle->ypos ), i )) {
             punitlist ul  = unitlist[i];
             while ( ul ) {
@@ -1449,11 +1449,16 @@ pair<int,int> calcMoveMalus( const MapCoordinate3D& start,
            // flying
            movecost = maxmalq;
         else {
-           int mm = getfield( start.x, start.y )->getContainer()->vehicleUnloadSystem( vehicle->typ, dest.getBitmappedHeight() )->movecost;
-           if ( mm > 0 )
-              movecost = mm;
-           else
-              movecost = getfield( dest.x, dest.y )->getmovemalus( vehicle );
+           if ( start.getNumericalHeight() <= 1 && start.getNumericalHeight() != -1 ) {
+              movecost = submarineMovement;
+              checkWind = false;
+           } else {
+              int mm = getfield( start.x, start.y )->getContainer()->vehicleUnloadSystem( vehicle->typ, dest.getBitmappedHeight() )->movecost;
+              if ( mm > 0 )
+                 movecost = mm;
+              else
+                 movecost = getfield( dest.x, dest.y )->getmovemalus( vehicle );
+           }
         }
       } else {
         // moving from one container to another
