@@ -21,6 +21,7 @@
 
 #include <algorithm>
 #include <ctime>
+#include <cmath>
 
 #include "global.h"
 #include "misc.h"
@@ -48,6 +49,7 @@ const int MineBasePunch[cminenum]  = { 60, 120, 180, 180 };
 
 tmap :: tmap ( void )
 {
+   randomSeed = rand();
 
    eventID = 0;
 
@@ -125,7 +127,7 @@ tmap :: tmap ( void )
 }
 
 
-const int tmapversion = 7;
+const int tmapversion = 8;
 
 void tmap :: read ( tnstream& stream )
 {
@@ -416,6 +418,9 @@ void tmap :: read ( tnstream& stream )
           events.push_back ( ev );
        }
     }
+
+    if ( version >= 8 )
+       randomSeed = stream.readInt();
 }
 
 
@@ -618,6 +623,9 @@ void tmap :: write ( tnstream& stream )
     stream.writeInt ( events.size());
     for ( Events::iterator i = events.begin(); i != events.end(); ++i )
        (*i)->write( stream );
+
+    if ( tmapversion >= 8 )
+       stream.writeInt( randomSeed );
 }
 
 
@@ -1014,6 +1022,8 @@ bool tmap :: compareResources( tmap* replaymap, int player, ASCString* log )
    }
 
    return diff;
+   #else
+   return true;
    #endif
 }
 
@@ -1108,7 +1118,10 @@ void tmap::endRound()
 {
     actplayer = 0;
     time.set ( time.turn()+1, 0 );
-    clearfahrspuren();
+
+    for ( int y = 0; y < ysize; ++y )
+       for ( int x = 0; x < xsize; ++x )
+           getField(x,y)->endRound( time.turn() );
 
     for (int i = 0; i <= 7; i++)
        if (player[i].exist() ) {
@@ -1136,6 +1149,49 @@ void tmap::endRound()
           } while ( didSomething );
           doresearch( this, i );
        }
+
+    if ( getgameparameter( cgp_objectGrowthMultiplier) > 0 )
+       objectGrowth();
+}
+
+#include "libs/rand/rand_r.h"
+#include "libs/rand/rand_r.c"
+
+int tmap::random( int max )
+{
+   return rand_r( &randomSeed ) % max;
+}
+
+void tmap::objectGrowth()
+{
+   typedef vector< pair<pfield,int> > NewObjects;
+   NewObjects newObjects;
+   for ( int y = 0; y < ysize; ++y )
+      for ( int x = 0; x < xsize; ++x ) {
+          pfield fld = getField( x, y );
+          for ( tfield::ObjectContainer::iterator i = fld->objects.begin(); i != fld->objects.end(); ++i)
+             if ( i->typ->growthRate > 0 )
+                for ( int d = 0; d < 6; ++d ) {
+                   pfield fld2 = getField ( getNeighbouringFieldCoordinate( MapCoordinate(x,y), d ));
+                   if ( fld2 && (!fld2->vehicle || fld2->vehicle->height >= chtieffliegend) && !fld2->building ) 
+                      if ( fld2->objects.empty() || getgameparameter( cgp_objectGrowOnOtherObjects ) > 0 ) {
+                        double d = i->typ->growthRate * getgameparameter( cgp_objectGrowthMultiplier) / 100;
+                        if ( d > 0 ) {
+                           if ( d > 0.9 )
+                              d = 0.9;
+
+                           int p = std::ceil ( double(1) / d) ;
+                           if ( p > 1 )
+                              if ( random ( p ) == 1 )
+                                 if ( i->typ->fieldModification[fld2->getweather()].terrainaccess.accessible( fld2->bdt) > 0 )
+                                    newObjects.push_back( make_pair( fld2, i->typ->id ));
+                        }
+                   }
+                }
+      }
+
+   for ( NewObjects::iterator i = newObjects.begin(); i != newObjects.end(); ++i )
+      i->first->addobject ( getobjecttype_byid( i->second ));
 }
 
 
@@ -1644,6 +1700,41 @@ void tfield::init ()
 
 
 
+bool AgeableItem::age( AgeableItem& obj )
+{
+   if ( obj.lifetimer > 0 ) {
+      --obj.lifetimer;
+      return obj.lifetimer==0;
+   } else
+      return false;
+}
+
+void tfield::endRound( int turn )
+{
+   bool recalc = false;
+   for ( ObjectContainer::iterator i = objects.begin(); i != objects.end(); ) {
+      if ( AgeableItem::age( *i )) {
+         i = objects.erase(i);
+         recalc = true;
+      } else
+         ++i;
+   }
+   // remove_if( objects.begin(), objects.end(), Object::age );
+
+   for ( MineContainer::iterator i = mines.begin(); i != mines.end(); ) {
+      if ( AgeableItem::age( *i )) {
+         i = mines.erase(i);
+         recalc = true;
+      } else
+         ++i;
+   }
+   // remove_if( mines.begin(), mines.end(), Object::age );
+
+   if ( recalc )
+      setparams();
+}
+
+
 void tfield::operator= ( const tfield& f )
 {
    typ = f.typ;
@@ -1669,18 +1760,17 @@ void tfield::operator= ( const tfield& f )
       view[i] = f.view[i];
 }
 
-void tfield :: checkminetime ( int time )
+
+Mine::Mine( MineTypes type, int strength, int player, tmap* gamemap )
 {
-   for ( MineContainer::iterator m = mines.begin(); m != mines.end();  ) {
-      int lt = gamemap->getgameparameter ( GameParameter(cgp_antipersonnelmine_lifetime + m->type - 1));
-      if ( lt && m->time + lt < time )
-         m = mines.erase( m );
-      else
-         m++;
-   }
+   this->type = type;
+   this->strength = strength;
+   this->player = player;
+   lifetimer = gamemap->getgameparameter( GameParameter(cgp_antipersonnelmine_lifetime + type - 1));
 }
 
 
+
 int tfield :: mineattacks ( const pvehicle veh )
 {
    int i = 1;
@@ -1722,7 +1812,6 @@ void  tfield :: addobject( pobjecttype obj, int dir, bool force )
 
      if ( buildable ) {
          Object o ( obj );
-         o.time = gamemap->time.turn();
          if ( dir != -1 )
             o.dir = dir;
          else
@@ -1740,6 +1829,7 @@ void  tfield :: addobject( pobjecttype obj, int dir, bool force )
       if ( dir != -1 )
          i->dir |= dir;
 
+      i->lifetimer = obj->lifetime;
       sortobjects();
    }
 }
@@ -1831,26 +1921,18 @@ void tfield :: sortobjects ( void )
    sort ( objects.begin(), objects.end(), compareObjectHeight );
 }
 
-
 bool  tfield :: putmine( int col, int typ, int strength )
 {
    if ( mineowner() >= 0  && mineowner() != col )
-      return 0;
+      return false;
 
    if ( mines.size() >= gamemap->getgameparameter ( cgp_maxminesonfield ))
-      return 0;
+      return false;
 
-   Mine m;
-   m.strength = strength ;
-   m.player = col;
-   m.type = MineTypes(typ);
-   if ( gamemap && gamemap->time.turn() >= 0 )
-      m.time = gamemap->time.turn();
-   else
-      m.time = 0;
-
-   mines.push_back ( m );
-   return 1;
+   MineTypes mt =  MineTypes(typ);
+   Mine mymine ( mt, strength, col, gamemap );
+   mines.push_back ( mymine );
+   return true;
 }
 
 int tfield :: mineowner( void )
@@ -2031,6 +2113,7 @@ Object :: Object ( void )
 
 Object :: Object ( pobjecttype t )
 {
+   lifetimer = t->lifetime;
    typ = t;
    dir = 0;
    damage = 0;
@@ -2398,7 +2481,10 @@ const int gameparameterdefault [ gameparameternum ] = { 1,
                                                         1,                       //       gp_experienceDivisorAttack
                                                         0,                       //       cgp_disableDirectView
                                                         0,                       //       cgp_disableUnitTransfer
-                                                        1 };                     //       cgp_experienceDivisorDefense
+                                                        1,                       //       cgp_experienceDivisorDefense
+                                                        0,                       //       cgp_debugEvents
+                                                        0,                       //       cgp_objectGrowthMultiplier
+                                                        0 };                     //       cgp_objectGrowOnOtherObjects
 
 
 const bool gameParameterChangeableByEvent [ gameparameternum ] = { true,   //       cgp_fahrspur
@@ -2429,7 +2515,10 @@ const bool gameParameterChangeableByEvent [ gameparameternum ] = { true,   //
                                                                  false,    //       cgp_experienceDivisorAttack };
                                                                  false,    //       cgp_disableDirectView
                                                                  false,    //       cgp_disableUnitTransfer
-                                                                 false };  //       cgp_experienceDivisorDefense
+                                                                 false,    //       cgp_experienceDivisorDefense
+                                                                 true,     //       cgp_debugEvents
+                                                                 true,     //       cgp_objectGrowthMultiplier
+                                                                 false };  //       cgp_objectGrowOnOtherObjects
 
 const int gameParameterLowerLimit [ gameparameternum ] = { 1,    //       cgp_fahrspur
                                                            1,    //       cgp_eis,
@@ -2459,7 +2548,12 @@ const int gameParameterLowerLimit [ gameparameternum ] = { 1,    //       cgp_fa
                                                            1,    //       gp_experienceDivisorAttack
                                                            0,    //       cgp_disableDirectView
                                                            0,    //       cgp_disableUnitTransfer
-                                                           1 };  //       cgp_experienceDivisorDefense
+                                                           1,    //       cgp_experienceDivisorDefense
+                                                           0,    //       cgp_debugEvents
+                                                           0,    //       cgp_objectGrowthMultiplier
+                                                           0 };  //       cgp_objectGrowOnOtherObjects
+
+
 
 const int gameParameterUpperLimit [ gameparameternum ] = { maxint,                //       cgp_fahrspur
                                                            maxint,                //       cgp_eis,
@@ -2489,7 +2583,11 @@ const int gameParameterUpperLimit [ gameparameternum ] = { maxint,
                                                            10,                    //       cgp_experienceDivisorAttack;
                                                            1,                     //       cgp_disableDirectView
                                                            1,                     //       cgp_disableUnitTransfer
-                                                           10 };                  //       cgp_experienceDivisorDefense
+                                                           10,                    //       cgp_experienceDivisorDefense
+                                                           2,                     //       cgp_debugEvents
+                                                           maxint,                //       cgp_objectGrowthMultiplier
+                                                           1 };                   //       cgp_objectGrowOnOtherObjects
+
 
 const char* gameparametername[ gameparameternum ] = { "lifetime of tracks",
                                                       "freezing time of icebreaker fairway",
@@ -2519,5 +2617,8 @@ const char* gameparametername[ gameparameternum ] = { "lifetime of tracks",
                                                       "experience effect divisor for attack",
                                                       "disable direct View",
                                                       "disable transfering units/buildings to other players",
-                                                      "experience effect divisor for defense" };
+                                                      "experience effect divisor for defense",
+                                                      "debug game events",
+                                                      "Object growth rate (percentage)",
+                                                      "Objects can grow on files with other objects" };
 
