@@ -97,6 +97,11 @@ int          terrainaccessible2 ( const pfield        field, const Vehicle*
       return 0;
 
 
+   return terrainaccessible2( field, vehicle->typ->terrainaccess, uheight );
+}
+
+int          terrainaccessible2 ( const pfield        field, const TerrainAccess& terrainAccess, int uheight )
+{
    if ( uheight >= chtieffliegend)
       return 2;
    else {
@@ -112,15 +117,22 @@ int          terrainaccessible2 ( const pfield        field, const Vehicle*
               else
                  return -2;
            else {
-              if ( vehicle->typ->terrainaccess.accessible ( field->bdt ) > 0 )
-                 return 2;
-              else
+              if ( terrainAccess.accessible ( field->bdt ) > 0 ) {
+                 if ( uheight == chschwimmend ) {
+                    if ( (field->bdt & getTerrainBitType(cbwater)).any() )
+                       return 2;
+                    else
+                       return -3;
+                 } else
+                    return 2;
+              } else
                  return -3;
             }
    }
 }
 
 
+
 int         fieldAccessible( const pfield        field,
                             const pvehicle     vehicle,
                             int  uheight,
@@ -601,31 +613,6 @@ void         tcursor::display(void)
 } 
 
 
-void         clearfahrspuren(void)
-{ 
-      if ((actmap->xsize == 0) || (actmap->ysize == 0)) 
-        return;
-      int l = 0; 
-      for ( int y = 0; y < actmap->ysize ; y++) 
-         for ( int x = 0; x < actmap->xsize ; x++) {
-            pobject i = actmap->field[l].checkforobject ( fahrspurobject );
-            if ( i ) 
-               if ( actmap->getgameparameter ( cgp_fahrspur ) > 0 )
-                  if ( i->time + actmap->getgameparameter ( cgp_fahrspur ) < actmap->time.turn() )
-                     getfield ( x, y ) -> removeobject ( fahrspurobject );
-
-            i = actmap->field[l].checkforobject ( eisbrecherobject );
-            if ( i ) 
-               if ( actmap->getgameparameter ( cgp_eis ) > 0 )
-                  if ( i->time + actmap->getgameparameter ( cgp_eis ) < actmap->time.turn() )
-                     getfield ( x, y ) -> removeobject ( eisbrecherobject );
-
-            getfield ( x, y )->checkminetime ( actmap->time.turn() );
-            l++;
-         } 
-} 
-
-
 
 void         putbuilding( const MapCoordinate& entryPosition,
                          int          color,
