@@ -45,6 +45,7 @@ const char* fileNameDelimitter = " =*/+<>,";
                virtual T parse ( const TextPropertyGroup::Entry& entry ) const;
                virtual T operation_mult ( const TextPropertyGroup::Entry& entry ) const;
                virtual T operation_add ( const TextPropertyGroup::Entry& entry ) const;
+               virtual T operation_sub ( const TextPropertyGroup::Entry& entry ) const;
                virtual T operation_eq ( const TextPropertyGroup::Entry& entry ) const;
 
 
@@ -162,6 +163,7 @@ const char* fileNameDelimitter = " =*/+<>,";
             protected:
               BitSet operation_eq ( const TextPropertyGroup::Entry& entry ) const;
               BitSet operation_add ( const TextPropertyGroup::Entry& entry ) const;
+              BitSet operation_sub ( const TextPropertyGroup::Entry& entry ) const;
               ASCString toString ( ) const;
             public:
                TagArrayProperty ( BitSet& property_, int tagNum_, const char** tags_, bool inverted_  ) : PTTA ( property_ ), tagNum (tagNum_), tags ( tags_ ), inverted ( inverted_ ) {};
@@ -175,6 +177,7 @@ const char* fileNameDelimitter = " =*/+<>,";
             protected:
               int operation_eq ( const TextPropertyGroup::Entry& entry ) const ;
               int operation_add ( const TextPropertyGroup::Entry& entry ) const ;
+              int operation_sub ( const TextPropertyGroup::Entry& entry ) const ;
               ASCString toString ( ) const;
             public:
                TagIntProperty ( int& property_, int tagNum_, const char** tags_, bool inverted_  ) : PTTI ( property_ ), tagNum (tagNum_), tags ( tags_ ), inverted ( inverted_ ) {};
@@ -241,7 +244,7 @@ void PropertyWritingContainer :: writeProperty ( Property& p, const ASCString& v
    output += p.getLastName();
    output +=  " = ";
 
-   int indent = output.length();
+   size_t indent = output.length();
    ASCString::size_type pos = value.find ( "\n" );
    if ( pos != ASCString::npos ) {
       output += "[";
@@ -491,7 +494,7 @@ PropertyReadingContainer :: ~PropertyReadingContainer (  )
 {
    closeBracket();
    if ( levelDepth )
-      error ( "PropertyWritingContainer :: ~PropertyWritingContainer - still brackets open" );
+      error ( "PropertyReadingContainer :: ~PropertyReadingContainer - still brackets open" );
 }
 
 PropertyWritingContainer :: PropertyWritingContainer ( const ASCString& baseName, tnstream& stream ) : PropertyContainer ( baseName, NULL, false ), stream ( stream )
@@ -556,6 +559,7 @@ T PropertyTemplate<T>::parse ( const TextPropertyGroup::Entry& entry ) const
    switch ( entry.op ) {
       case TextPropertyGroup::Entry::mult_eq : return operation_mult ( entry );
       case TextPropertyGroup::Entry::add_eq :  return operation_add ( entry );
+      case TextPropertyGroup::Entry::sub_eq :  return operation_sub ( entry );
    }
    propertyContainer->error ( "PropertyTemplate::parse - invalid operator !");
    return defaultValue;
@@ -589,6 +593,14 @@ T PropertyTemplate<T>::operation_add ( const TextPropertyGroup::Entry& entry ) c
    return T();
 }
 
+template <class T>
+T PropertyTemplate<T>::operation_sub ( const TextPropertyGroup::Entry& entry ) const
+{
+   operation_not_defined( entry );
+   return T();
+}
+
+
 template <class T>
 void PropertyTemplate<T>::evaluate ()
 {
@@ -889,6 +901,12 @@ BitSet TagArrayProperty::operation_add ( const TextPropertyGroup::Entry& entry )
    return parse ( *entry.parent ) | operation_eq ( entry );
 }
 
+BitSet TagArrayProperty::operation_sub ( const TextPropertyGroup::Entry& entry ) const
+{
+   return parse ( *entry.parent ) & ~operation_eq ( entry );
+}
+
+
 BitSet TagArrayProperty::operation_eq ( const TextPropertyGroup::Entry& entry ) const
 {
    BitSet bs;
@@ -936,6 +954,12 @@ int TagIntProperty::operation_add ( const TextPropertyGroup::Entry& entry ) cons
    return parse ( *entry.parent ) | operation_eq ( entry );
 }
 
+int TagIntProperty::operation_sub ( const TextPropertyGroup::Entry& entry ) const
+{
+   return parse ( *entry.parent ) & ~operation_eq ( entry );
+}
+
+
 int TagIntProperty::operation_eq ( const TextPropertyGroup::Entry& entry ) const
 {
    int i;
@@ -1145,7 +1169,7 @@ ImageArrayProperty::PropertyType ImageArrayProperty::operation_eq ( const TextPr
 
 ASCString ImageArrayProperty::toString() const
 {
-   int num = property.size();
+   size_t num = property.size();
    tvirtualdisplay vdp ( 1100, 100 * (num / 10 + 1), 255, 8 );
    int cnt = 0;
    for ( PropertyType::iterator i = property.begin(); i != property.end(); i++ ) {
